@@ -8,7 +8,7 @@ with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
 
 setup(
     name='garpix_notify',
-    version='3.0.1',
+    version='4.0.2',
     description='',
     long_description=long_description,
     url='https://github.com/garpixcms/garpix_notify',
@@ -33,14 +33,14 @@ setup(
     install_requires=[
         'Django >= 1.11',
         'django-solo >= 1.1.3',
-        'fcm-django >= 0.2.19',
+        'fcm-django == 0.3.11',
         'requests >= 2.18.4',
         'django-ckeditor >= 5.6.1',
         'python-telegram-bot >= 12.6.1',
         'viberbot >= 1.0.11',
         'django-uuslug >= 1.2.0',
         'Pillow >= 8.2.0',
-        'celery==4.4.2',
+        'celery>=4.4.2',
         'redis >= 3.5.3',
     ],
 )
